package com.caimei365.manager.controller.wechat;

import com.caimei365.manager.config.security.ConstantKey;
import com.caimei365.manager.config.security.JwtService;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.wechat.WechatMenu;
import com.caimei365.manager.service.wechat.WechatMenuService;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * 微信公众号菜单
 *
 * @author : Charles
 * @date : 2022/1/4
 */
@RestController
@RequestMapping("/wechat/menu")
public class WechatMenuApi {

    @Resource
    private WechatMenuService wechatMenuService;
    @Resource
    private JwtService jwtService;

    /**
     * 获取微信公众号菜单列表
     *
     * @param type 类型： 1采美，2呵呵商城
     */
    @GetMapping("/list")
    public ResponseJson<List<WechatMenu>> wechatMenuList(Integer type) {
        return wechatMenuService.getWechatMenuList(type);
    }

    /**
     * 根据ID获取微信公众号菜单
     */
    @GetMapping("/{id}")
    public ResponseJson<WechatMenu> getWechatMenu(@PathVariable("id") Integer id) {
        if (null == id || id <= 0) {
            return ResponseJson.error("菜单Id不能为空！", null);
        }
        return wechatMenuService.getWechatMenu(id);
    }

    /**
     * 根据ID更新微信公众号菜单
     */
    @PostMapping("/update/{id}")
    public ResponseJson<Void> updateWechatMenu(HttpServletRequest request, @PathVariable("id") Integer id, @RequestBody WechatMenu menu) {
        if (null == id || id <= 0) {
            return ResponseJson.error("菜单Id不能为空！", null);
        }
        String token = request.getHeader(ConstantKey.TOKEN_NAME);
        String username = jwtService.getUsername(token);
        return wechatMenuService.updateWechatMenu(id, menu, username);
    }

    /**
     * 添加微信公众号菜单
     */
    @PostMapping("/create")
    public ResponseJson<Void> addWechatMenu(HttpServletRequest request, @RequestBody WechatMenu menu) {
        String token = request.getHeader(ConstantKey.TOKEN_NAME);
        String username = jwtService.getUsername(token);
        return wechatMenuService.addWechatMenu(menu, username);
    }

    /**
     * 根据ID删除微信公众号菜单
     */
    @PostMapping("/delete/{id}")
    public ResponseJson<Void> deleteWechatMenu(@PathVariable("id") Integer id) {
        if (null == id || id <= 0) {
            return ResponseJson.error("菜单Id不能为空！", null);
        }
        return wechatMenuService.deleteWechatMenu(id);
    }

    /**
     * 微信公众号菜单发布
     * @param type 类型： 1采美，2呵呵商城
     */
    @PostMapping("/push/{type}")
    public ResponseJson<Void> pushWechatMenu(@PathVariable("type") Integer type) {
        return wechatMenuService.pushWechatMenu(type);
    }
}
